@@ -10,7 +10,7 @@ import os
 from pathlib import Path
 
 
-__version__ = "0.1.1"
+__version__ = "0.1.2"
 
 
 StrBytes = Union[str, bytes]
@@ -85,6 +85,9 @@ async def run(
     if capture_output:
         stdout = subprocess.PIPE
         stderr = subprocess.PIPE
+    else:
+        stdout = subprocess.DEVNULL
+        stderr = subprocess.DEVNULL
 
     proc = await asyncio.create_subprocess_exec(
         *args,
